"use client";

import React, { useState } from "react";
import styles from "@/style/form.module.css"
import { Product } from "types/Product";

type FormProps = {
  onSubmit: (product: Product) => void;
};

export default function Form({ onSubmit }: FormProps) {
  const [formOpen, setFormOpen] = useState(false);
  const [formState, setFormState] = useState({
    img: "",
    name: "",
    price: "",
    description: "",
  });

  function generateId() {
    return Math.floor(Math.random() * 999 + 1).toString();
  }

  function handleChange(e: React.ChangeEvent<HTMLInputElement>) {
    const { name, value } = e.target;
    setFormState((prev) => ({ ...prev, [name]: value }));
  }

  function handleSubmit() {
    if (!formState.img || !formState.name || !formState.price) return;

    const product: Product = {
      id: generateId(),
      alt: `img-${formState.img}`,
      ...formState,
    };

    onSubmit(product);
    setFormState({ img: "", name: "", price: "", description: "" });
    setFormOpen(false);
  }

  return formOpen ? (
    <div className={styles["form-container"]}>
      <label>Image</label>
      <input name="img" value={formState.img} onChange={handleChange} />
      <label>Name</label>
      <input name="name" value={formState.name} onChange={handleChange} />
      <label>Price</label>
      <input name="price" value={formState.price} onChange={handleChange} />
      <label>Description</label>
      <input
        name="description"
        value={formState.description}
        onChange={handleChange}
      />
      <button onClick={handleSubmit}>Add</button>
    </div>
  ) : (
    <button className={styles["fab"]} onClick={() => setFormOpen(true)}>
      <i className="material-icons">add_circle</i> Add Product
    </button>
  );
}
