"use client";

import styles from "./page.module.css";
import Table from "../components/Table";
import Heading from "../components/Heading";
import { initialProductList } from "@/data/product";
import Form from "../components/Form/Form";
import { useActionState, startTransition } from "react";
import { Product } from "types/Product";

type Action =
  | { type: "ADD"; payload: Product }
  | { type: "DELETE"; payload: number };

export default function Home() {

  const [products, setProducts] = useActionState(
    (prev: Product[], action: Action): Product[] => {
      switch (action.type) {
        case "ADD":
          return [...prev, action.payload];
        case "DELETE":
          return prev.filter((_, i) => i !== action.payload);
        default:
          return prev;
      }
    },
    initialProductList
  );

  const onAdd = (product: Product) => {
    startTransition(() => {
      setProducts({ type: "ADD", payload: product });
    });
  };

  const onDelete = (index: number) => {
    startTransition(() => {
      setProducts({ type: "DELETE", payload: index });
    });
  };

  return (
    <div className={styles.page}>
      <Heading title="Products"/>
      <Table list={products} onDelete={onDelete} />
      <Form onSubmit={onAdd}/>
    </div>
  );
}
