import { Product } from "types/Product";
import Image from "next/image";
import Link from "next/link";

type Props = {
  list: Product[];
  onDelete: (index: number) => void
};

const TableBody = (props: Props) => {
  const { list, onDelete } = props
  return (
    <tbody>
      {list?.map((item, index) => {
        return (
          <tr key={index}>
            <td>
              <Image
                src={item?.img}
                alt={item?.alt || ""}
                width={50}
                height={50}
                priority
                unoptimized />
            </td>
            <td>{item?.name}</td>
            <td>{item?.price}</td>
            <td>{item?.description}</td>
            <td>
              <div className={"actionButton"}>
                <button className="btn-icon" onClick={() => onDelete(index)}>
                  <i className="material-icons">delete</i>
                </button>
                <Link
                  href={{
                    pathname: `/product/detail/${index}`,
                    query: { image: item.img, alt: item.alt, name: item.name, price: item.price, description: item.description },
                  }}
                >
                  <i className="material-icons">link</i>
                </Link>
              </div>
            </td>
          </tr>
        )
      })}
    </tbody>
  )
}

export default TableBody